*===================================================================================================;
*  Title:  PROGRAM P2 CALCULATES OBSERVED PROVIDER RATES FOR AHRQ
*          PEDIATRIC QUALITY INDICATORS
*
*  Description:;
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PEDIATRIC QUALITY INDICATORS ACROSS STRATIFIERS.
*         PROGRAM USES HOSPID, BWHTCAT, AGEDCAT, PAGECAT, SEXCAT, 
*         PAYCAT, RACECAT.
*
*          >>>  VERSION 4.5, MAY 2013   <<<
*
*  USER NOTE: Version 4.5 AHRQ QI SAS software does not explicitly support the calculation 
*             of weighted estimates and standard errors using complex sampling designs.
*             The variable DISCWT (discharge weight) is set equal to 1 in the SAS1 program  
*             for this module, and consequently the variable does not weight any calculations   
*             in this program.If a DISCWT variable is present in the users dataset, 
*             all values are set to 1. 
*
*             In order to obtain weighted nationally representative estimates, additional 
*             calculations will need to be performed.  
*             For a more thorough description of weighted AHRQ QI analyses beginning with 
*             AHRQ QI SAS Version 4.1, see the technical documentation on the AHRQ QI website.
*==================================================================================================;

FILENAME CONTROL 'C:\PATHNAME\CONTROL_PS17.SAS';  *<===USER MUST modify;

%INCLUDE CONTROL;


TITLE2 'PROGRAM: P2';
 TITLE3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE OBSERVED PROVIDER RATES';

 * -------------------------------------------------------------- ;
 * --- PROVIDER LEVEL MEANS ON PEDIATRIC DATA FILE  ------------- ;
 * -------------------------------------------------------------- ;

 DATA   TEMP0;
 SET    IN1.&INFILE1.;
 RUN;

 PROC   SUMMARY DATA=TEMP0;
 CLASS  HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 VAR    TPPS17;
 OUTPUT OUT=&OUTFILP2.
        SUM (TPPS17)=
        SUMWGT(TPPS17)= PPPS17
        MEAN(TPPS17)= OPPS17;
 WEIGHT DISCWT;
 RUN;

 PROC   SORT DATA=&OUTFILP2.;
 BY HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 RUN;

 DATA   OUTP2.&OUTFILP2.;
 SET    &OUTFILP2. (WHERE=(_TYPE_ &TYPELVLP))
;

 LABEL
 TPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Numerator)'
 PPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Population)'
 OPPS17 = 'PSI #17 Birth Trauma Rate - Injury to Neonate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
;
 DROP _FREQ_ ;

 RUN;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 PROC   CONTENTS DATA=OUTP2.&OUTFILP2. POSITION;
 RUN;

 PROC   MEANS DATA=OUTP2.&OUTFILP2. (WHERE=(_TYPE_ IN (64))) N NMISS MIN MAX MEAN SUM NOLABELS;
 TITLE4 "SUMMARY OF PROVIDER-LEVEL RATES (_TYPE_=64)";
 RUN;

 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE ----------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,VOLUME);

 PROC   PRINT DATA=OUTP2.&OUTFILP2. LABEL SPLIT='*';
 %IF &VOLUME=0 %THEN %DO;
 VAR    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD. PP&PD. OP&PD. ;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       PP&PD.   = "PP&PD.*(Denominator)"
       OP&PD.   = "OP&PD.*(Observed)"
       ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. PP&PD. 13.0 OP&PD. 8.6;
 %END;
 %ELSE %DO;
 VAR    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD.  ;
 LABEL HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       ;
 FORMAT BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. 13.0;
 %END;
 TITLE4 "Indicator # &PD.: &TEXT";

 RUN;

 %MEND PRT;

 %PRT(PS17,Birth Trauma Rate - Injury to Neonate,0);

 %END;

 %MEND PRT2;

 %PRT2;


 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTP2;

 %IF &TEXTP2. = 1  %THEN %DO;

 DATA _NULL_;
   SET OUTP2.&OUTFILP2.;
 FILE PDTEXTP2 LRECL=2000;
 IF _N_=1 THEN PUT "Hosp Id" "," "BWht" "," "AgeD" "," "Age"  "," "Sex"  "," "Payer" "," "Race" "," "Type" ","
 "TPPS17" "," 
 "PPPS17" "," 
 "OPPS17" 
 ;

 PUT HOSPID 13. "," BWHTCAT 3. "," AGEDCAT 3. "," PAGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPPS17) (7.0 ",")
  ","
 (PPPS17) (13.2 ",")
 ","
 (OPPS17) (12.10 ",")
 ;
 RUN;

 %END;

 %MEND TEXTP2;

 %TEXTP2;
